Superintendencia de Servicios de Salud

0800 222 SALUD (72583)
Menu
Usuario: USERTEST | HOSPITAL MILITAR | SALIR

### Consultas al Padrón de Beneficiarios de los Agentes Nacionales del Seguro de Salud

Sr. beneficiario

A través de esta página Ud. podrá acceder a los datos de los beneficiarios titulares y familiares a cargo incluidos en la Base de Datos del Padrón de afiliados que actualiza esta Superintendencia con los datos aportados por cada uno de los Agentes del Seguro de Salud con carácter de declaración jurada. Para ello deberá conocer previamente el número de CUIL o el Documento de Identidad de la persona buscada. Como resultado de la búsqueda obtendrá datos identificatorios del beneficiario y la Obra Social en la que se encuentra afiliado.
CUIL
Ingrese un CUIL con el formato:XX-XXXXXXXX-X
Numero de documento
Fecha de actualización: 01-06-2020
Fecha de proceso: 31-07-2020

DATOS DE AFILIACION VIGENTE
Datos personales
Parentesco | TITULAR
CUIL | 27-1XXXXX3-6
Tipo de documento
| DOCUMENTO UNICO
Número de documento | 1XXXXX3
Apellido y nombre | GOMEZ EDUARDO
Provincia | CAPITAL FEDERAL
Fecha de nacimiento | 25-05-1977
Sexo | Masculino

Datos de Afiliación

CUIL titular | 27-1XXXXX3-6
CUIT de empleador | 30-70818659-3
Tipo de beneficiario | RELACION DE DEPENDENCIA
Código de Obra Social | 4-0080-0
Denominación Obra Social | OBRA SOCIAL DE EJECUTIVOS Y DEL PERSONAL DE DIRECCION DE EMPRESAS
Fecha Alta Obra Social | 01-06-1931

Datos Declarados por el Empleador

Tipo Beneficiario Declarado | RELACION DE DEPENDENCIA (DDJJ SIJP)
Ultimo Período Declarado | 02-2020

• DATOS HISTORICOS ADICIONALES

Bajas producidas desde el año 2006 al 01-06-2020

Obra Social | CUIL Titular | Tipo Beneficiario | Fecha Alta/Baja | Motivo
--- | --- | --- | --- | ---
1-2570-7 | 27-1XXXXX3-6 | ADHERENTES VOLUNTARIOS | 20-05-2004/ 30-04-2015 | INFORMADA POR LA O.S.
0-0110-2 | 27-1XXXXX3-6 | RELACION DE DEPENDENCIA | 01-09-2000/ 31-05-2001 | IGUAL CUIT DECLARA OTRA OS

Cambiar Contrase�a